@@ -1,5 +1,4 @@
 import re
-from typing import Callable
 
 from git_machete import utils
 
@@ -13,11 +12,16 @@ class Qualifiers:
         self._annotation_without_qualifiers = annotation
         self._rebase_text = ''
         self._push_text = ''
+        self._slide_out_text = ''
         self.rebase = True
         self.push = True
+        self.slide_out = None
 
-        match_pattern: Callable[[str], str] = lambda text: f'.*\\b{text}=no\\b.*'
-        sub_pattern: Callable[[str], str] = lambda text: f'[ ]?{text}=no[ ]?'
+        def match_pattern(text: str) -> str:
+            return f'.*\\b{text}=no\\b.*'
+
+        def sub_pattern(text: str) -> str:
+            return f'[ ]?{text}=no[ ]?'
 
         rebase_match = re.match(match_pattern('rebase'), annotation)
         if rebase_match:
@@ -31,11 +35,17 @@ class Qualifiers:
             self._push_text = 'push=no'
             self._annotation_without_qualifiers = re.sub(sub_pattern('push'), ' ', self._annotation_without_qualifiers)
 
+        slide_out_match = re.match(match_pattern('slide-out'), annotation)
+        if slide_out_match:
+            self.slide_out = False
+            self._slide_out_text = 'slide-out=no'
+            self._annotation_without_qualifiers = re.sub(sub_pattern('slide-out'), ' ', self._annotation_without_qualifiers)
+
     def get_annotation_text_without_qualifiers(self) -> str:
         return self._annotation_without_qualifiers.strip()
 
     def get_qualifiers_text(self) -> str:
-        return f'{self._rebase_text.strip()} {self._push_text.strip()}'.replace('  ', ' ').strip()
+        return f'{self._rebase_text} {self._push_text} {self._slide_out_text}'.replace('  ', ' ').strip()
 
 
 class Annotation:
