@@ -71,9 +71,9 @@ class RemoteAndOrganizationAndRepository:
     def from_config(cls,
                     git: GitContext
                     ) -> "RemoteAndOrganizationAndRepository":
-        return RemoteAndOrganizationAndRepository(remote=git.get_config_attr_or_none(key=git_config_keys.GITHUB_REMOTE),
-                                                  organization=git.get_config_attr_or_none(key=git_config_keys.GITHUB_ORGANIZATION),
-                                                  repository=git.get_config_attr_or_none(key=git_config_keys.GITHUB_REPOSITORY))
+        return cls(remote=git.get_config_attr_or_none(key=git_config_keys.GITHUB_REMOTE),
+                   organization=git.get_config_attr_or_none(key=git_config_keys.GITHUB_ORGANIZATION),
+                   repository=git.get_config_attr_or_none(key=git_config_keys.GITHUB_REPOSITORY))
 
     @classmethod
     def from_url(cls,
@@ -86,37 +86,108 @@ class RemoteAndOrganizationAndRepository:
             if match:
                 org = match.group(1)
                 repo = match.group(2)
-                return RemoteAndOrganizationAndRepository(remote=remote,
-                                                          organization=org,
-                                                          repository=repo if repo[-4:] != '.git' else repo[:-4])
-        return RemoteAndOrganizationAndRepository(remote=None,
-                                                  organization=None,
-                                                  repository=None)
+                return cls(remote=remote,
+                           organization=org,
+                           repository=repo if repo[-4:] != '.git' else repo[:-4])
+        return cls(remote=None,
+                   organization=None,
+                   repository=None)
 
 
 class GitHubToken:
     GITHUB_TOKEN_ENV_VAR = 'GITHUB_TOKEN'
 
     def __init__(self,
-                 domain: str
+                 value: str,
+                 provider: str
                  ) -> None:
-        self.__domain = domain
-        self.__value: Optional[str] = None
-        self.__provider: Optional[str] = None
-        for token_retrieval_method in [self.__get_token_from_env,
-                                       self.__get_token_from_file_in_home_directory,
-                                       self.__get_token_from_gh,
-                                       self.__get_token_from_hub]:
-            if not (self.value and self.provider):
-                token_retrieval_method()
-            if self.value and self.provider:
-                debug("authenticating via " + self.provider)
-                break
+        self.__value = value
+        self.__provider = provider
+        debug("authenticating via " + self.provider)
 
-    def __bool__(self) -> bool:
-        return self.__value is not None and self.__provider is not None
+    @property
+    def value(self) -> Optional[str]:
+        return self.__value
 
-    def __get_token_from_hub(self) -> None:
+    @property
+    def provider(self) -> Optional[str]:
+        return self.__provider
+
+    @classmethod
+    def for_domain(cls, domain: str) -> Optional["GitHubToken"]:
+        return (cls.__get_token_from_env() or
+                cls.__get_token_from_file_in_home_directory(domain) or
+                cls.__get_token_from_gh(domain) or
+                cls.__get_token_from_hub(domain))
+
+    @classmethod
+    def __get_token_from_env(cls) -> Optional["GitHubToken"]:
+        debug(f"1. Trying to authenticate via `{cls.GITHUB_TOKEN_ENV_VAR}` environment variable...")
+        github_token = os.environ.get(cls.GITHUB_TOKEN_ENV_VAR)
+        if github_token:
+            return cls(value=github_token,
+                       provider=f'`{cls.GITHUB_TOKEN_ENV_VAR}` environment variable')
+        return None
+
+    @classmethod
+    def __get_token_from_file_in_home_directory(cls, domain: str) -> Optional["GitHubToken"]:
+        debug("2. Trying to authenticate via `~/.github-token`...")
+        required_file_name = '.github-token'
+        provider = f'auth token for {domain} from `~/.github-token`'
+        file_full_path = os.path.expanduser(f'~/{required_file_name}')
+
+        if os.path.isfile(file_full_path):
+            with open(file_full_path) as file:
+                # ~/.github-token is a file with a structure similar to:
+                #
+                # ghp_mytoken_for_github_com
+                # ghp_myothertoken_for_git_example_org git.example.org
+                # ghp_yetanothertoken_for_git_example_com git.example.com
+
+                for line in file.readlines():
+                    if line.endswith(" " + domain):
+                        token = line.split(" ")[0]
+                        return cls(value=token, provider=provider)
+                    elif domain == GitHubClient.DEFAULT_GITHUB_DOMAIN and " " not in line.rstrip():
+                        return cls(value=line.rstrip(), provider=provider)
+        return None
+
+    @classmethod
+    def __get_token_from_gh(cls, domain: str) -> Optional["GitHubToken"]:
+        debug("3. Trying to authenticate via `gh` GitHub CLI...")
+        # Abort without error if `gh` isn't available
+        gh = shutil.which('gh')
+        if not gh:
+            return None
+
+        # There is also `gh auth token`, but it's only been added in gh v2.17.0, in Oct 2022.
+        # Let's stick to the older `gh auth status --show-token` for compatibility.
+        proc = subprocess.run(
+            [gh, "auth", "status", "--hostname", domain, "--show-token"],
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE
+        )
+        if proc.returncode != 0:
+            return None
+
+        # `gh auth status --show-token` outputs to stderr in the form:
+        #
+        # {domain}:
+        #   ✓ Logged in to {domain} as {username} ({config_path})
+        #   ✓ Git operations for {domain} configured to use {protocol} protocol.
+        #   ✓ Token: <token>
+        #
+        # with non-zero exit code on failure.
+        stderr = proc.stderr.decode()
+        match = re.search(r"Token: (\w+)", stderr)
+        if match:
+            return cls(value=match.group(1),
+                       provider=f'auth token for {domain} from `gh` GitHub CLI')
+        return None
+
+    @classmethod
+    def __get_token_from_hub(cls, domain: str) -> Optional["GitHubToken"]:
+        debug("4. Trying to authenticate via `hub` GitHub CLI...")
         home_path: str = str(Path.home())
         config_hub_path: str = os.path.join(home_path, ".config", "hub")
         if os.path.isfile(config_hub_path):
@@ -134,71 +205,13 @@ class GitHubToken:
                 #   protocol: {protocol}
                 found_host = False
                 for line in config_hub.readlines():
-                    if line.rstrip() == self.__domain + ":":
+                    if line.rstrip() == domain + ":":
                         found_host = True
                     elif found_host and line.lstrip().startswith("oauth_token:"):
-                        result = re.sub(' *oauth_token: *', '', line).rstrip().replace('"', '')
-                        self.__value = result
-                        self.__provider = f'auth token for {self.__domain} from `hub` GitHub CLI'
-                        break
-
-    def __get_token_from_gh(self) -> None:
-        # Abort without error if `gh` isn't available
-        gh = shutil.which('gh')
-        if not gh:
-            return
-
-        # There is also `gh auth token`, but it's only been added in gh v2.17.0, in Oct 2022.
-        # Let's stick to the older `gh auth status --show-token` for compatibility.
-        proc = subprocess.run(
-            [gh, "auth", "status", "--hostname", self.__domain, "--show-token"],
-            stdout=subprocess.PIPE,
-            stderr=subprocess.PIPE
-        )
-        if proc.returncode != 0:
-            return
-
-        # `gh auth status --show-token` outputs to stderr in the form:
-        #
-        # {domain}:
-        #   ✓ Logged in to {domain} as {username} ({config_path})
-        #   ✓ Git operations for {domain} configured to use {protocol} protocol.
-        #   ✓ Token: <token>
-        #
-        # with non-zero exit code on failure.
-        stderr = proc.stderr.decode()
-        match = re.search(r"Token: (\w+)", stderr)
-        if match:
-            self.__value = match.group(1)
-            self.__provider = f'auth token for {self.__domain} from `hub` GitHub CLI'
-
-    def __get_token_from_env(self) -> None:
-        github_token = os.environ.get(self.GITHUB_TOKEN_ENV_VAR)
-        if github_token:
-            self.__value = github_token
-            self.__provider = f'`{self.GITHUB_TOKEN_ENV_VAR}` environment variable'
-
-    def __get_token_from_file_in_home_directory(self) -> None:
-        required_file_name = '.github-token'
-        self.__provider = f'auth token for {self.__domain} from `~/.github-token`'
-        file_full_path = os.path.expanduser(f'~/{required_file_name}')
-
-        if os.path.isfile(file_full_path):
-            with open(file_full_path) as file:
-                for line in file.readlines():
-                    if line.endswith(" " + self.__domain):
-                        token = line.split(" ")[0]
-                        self.__value = token
-                    elif self.__domain == GitHubClient.DEFAULT_GITHUB_DOMAIN and " " not in line.rstrip():
-                        self.__value = line.rstrip()
-
-    @property
-    def value(self) -> Optional[str]:
-        return self.__value
-
-    @property
-    def provider(self) -> Optional[str]:
-        return self.__provider
+                        result = re.sub(' *oauth_token:  *', '', line).rstrip().replace('"', '')
+                        return cls(value=result,
+                                   provider=f'auth token for {domain} from `hub` GitHub CLI')
+        return None
 
     @classmethod
     def get_possible_providers(cls) -> str:
@@ -219,7 +232,7 @@ class GitHubClient:
         self.__domain: str = domain
         self.__organization: str = organization
         self.__repository: str = repository
-        self.__token: GitHubToken = GitHubToken(domain=domain)
+        self.__token: Optional[GitHubToken] = GitHubToken.for_domain(domain)
 
     @property
     def organization(self) -> str:
@@ -282,7 +295,7 @@ class GitHubClient:
                 else:
                     raise MacheteException(
                         first_line + f'You might not have the required permissions for this repository.\n'
-                                     f'Provide a GitHub API token with `repo` access via {self.__token.provider}.\n'
+                                     f'Provide a GitHub API token with `repo` access.\n'
                                      f'Visit `https://{self.__domain}/settings/tokens` to generate a new one.\n'
                                      'You can also use a different token provider, available providers can be found '
                                      'when running `git machete help github`.')
